@@ -216,7 +216,21 @@ delayed_focus_handler(gpointer user_data)
 static void
 focus_handler(GtkWindow *window)
 {
+  // Try to determine the screen state
+  FILE* lockfile = fopen("/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts", "r");
+  int lockstate = 0;
+  if (lockfile) {
+    fscanf(lockfile, "%d", &lockstate);
+    fclose(lockfile);
+  }
+
+  printf("Focus handler, lock state: %d\n", lockstate);
+
   if (gtk_window_is_active(window)) {
+    // Sometimes the window receives focus just after the screen is locked, but
+    // that does not mean that the emulation should be resumed just yet
+    if (lockstate) return;
+
     // Focus received, resume the game
     gtk_dialog_response(pause_dialog, 0);
     use_gpio_keys = TRUE;
@@ -227,22 +241,15 @@ focus_handler(GtkWindow *window)
     // + a notification popped up (do nothing)
     // + tasknav activated (pause the game, but leave it to topmost_handler)
 
-    // Try to determine the screen state
-    FILE* lockfile = fopen("/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts", "r");
-    int lockstate = 0;
-    if (lockfile) {
-      fscanf(lockfile, "%d", &lockstate);
-      fclose(lockfile);
-    }
-
     if (lockstate) {
       // Screen is locked, pause the game
       activate_pause(TRUE);
     } else {
-      // It is not certain what should be done, so wait a moment (3000 ms, which
-      // is for how long the screen is dimmed before blanking) and then decide
+      // At this point it is not certain what should be done, so wait a moment
+      // (about 3 seconds, which is for how long the screen is dimmed before
+      // blanking) and then decide
       g_source_remove(pause_timeout);
-      pause_timeout = gtk_timeout_add(3000, delayed_focus_handler, NULL);
+      pause_timeout = gtk_timeout_add(3500, delayed_focus_handler, NULL);
     }
   }
 }
@@ -321,6 +328,9 @@ accel_calibrate(GtkWidget *widget, gpointer user_data)
 
 static void activate_pause(int automatic)
 {
+  // Audio slowly drains the battery even when idle, shut it down
+  sound_disengage();
+
   use_gpio_keys = FALSE;
 
   if (pause_dialog || (automatic && !autopause)) return;
@@ -390,6 +400,8 @@ static void activate_pause(int automatic)
 
   gtk_widget_destroy (GTK_WIDGET(pause_dialog));
   pause_dialog = NULL;
+
+  sound_engage();
 }
 
 static void
