@@ -30,6 +30,10 @@ u32 sound_frequency = 44100;
 SDL_mutex *sound_mutex;
 static SDL_cond *sound_cv;
 
+#ifdef MAEMO_BUILD
+static SDL_AudioSpec sound_settings;
+#endif
+
 #ifdef PSP_BUILD
 u32 audio_buffer_size_number = 1;
 #else
@@ -736,9 +740,28 @@ void sound_exit()
   SDL_CloseAudio();
 }
 
+#ifdef MAEMO_BUILD
+void sound_disengage()
+{
+  SDL_PauseAudio(1);
+  sound_exit_flag = 1;
+  SDL_CondSignal(sound_cv);
+  SDL_CloseAudio();
+}
+
+void sound_engage()
+{
+  sound_exit_flag = 0;
+  SDL_OpenAudio(&sound_settings, NULL);
+  SDL_PauseAudio(0);
+}
+#endif
+
 void init_sound()
 {
+#ifndef MAEMO_BUILD
   SDL_AudioSpec sound_settings;
+#endif
 
 #ifdef PSP_BUILD
   audio_buffer_size = (audio_buffer_size_number * 1024) + 3072;
