@@ -326,4 +326,9 @@ static u32 gbc_sound_wave_volume[4] = { 0, 16384, 8192, 4096 };
 void reset_sound();
 void sound_exit();
 
+#ifdef MAEMO_BUILD
+void sound_disengage();
+void sound_engage();
+#endif
+
 #endif
